@@ -1,6 +1,6 @@
 package Net::DNS::Resolver;
 
-# $Id: Resolver.pm,v 1.16 2002/06/19 19:59:27 ctriv Exp $
+# $Id: Resolver.pm,v 1.17 2002/08/01 08:53:50 ctriv Exp $
 
 =head1 NAME
 
@@ -169,7 +169,6 @@ sub res_init {
 
 	# If we're running under a SOCKSified Perl, use TCP instead of UDP
 	# and keep the sockets open.
-
 	if ($Config::Config{'usesocks'}) {
 		$default{'usevc'} = 1;
 		$default{'persistent_tcp'} = 1;
@@ -1729,13 +1728,26 @@ Default udppacketsize is &Net::DNS::PACKETSZ (512)
 =cut
 
 sub AUTOLOAD {
-	my $self = shift;
+	my ($self) = @_;
+
 	my $name = $AUTOLOAD;
 	$name =~ s/.*://;
 
 	Carp::croak "$name: no such method" unless exists $self->{$name};
-	$self->{$name} = shift if @_;
-	return $self->{$name};
+	
+	no strict q/refs/;
+	
+	*{$AUTOLOAD} = sub {
+		my ($self, $new_val) = @_;
+		
+		if ($new_val) {
+			$self->{"$name"} = $new_val;
+		}
+		
+		return $self->{"$name"};
+	};
+	
+	goto &{$AUTOLOAD};	
 }
 
 =head1 ENVIRONMENT
